@@ -83,11 +83,12 @@ class erstruct:
         print("K_hat is ", K_hat)
         return K_hat
 
-class Gene_sample:
-    def download_sample(self):
-        data1 = pkg_resources.resource_string("ERStruct", 'data/char21.npy')
-        data2 = pkg_resources.resource_string("ERStruct", 'data/char22.npy')
-        np.save('sample_data/char21.npy', data1)
-        np.save('sample_data/char22.npy', data2)
+
+def download_sample():
+    data1 = pkg_resources.resource_string("ERStruct", 'data/chr21.npy')
+    data2 = pkg_resources.resource_string("ERStruct", 'data/chr22.npy')
+    np.save('char21.npy', data1)
+    np.save('char22.npy', data2)
+    print('Sample data \"char21.npy\" and \"char22.npy\" are saved in the current directory')
 
 
